==> zio-aws-sesv2_3-5.17.129.2-sources.jar: zio/aws/sesv2/model/ListConfigurationSetsResponse.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.{NextToken, ConfigurationSetName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListConfigurationSetsResponse(
    configurationSets: Option[Iterable[ConfigurationSetName]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse = {
    import ListConfigurationSetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
      .builder()
      .optionallyWith(
        configurationSets.map(value =>
          value.map { item =>
            ConfigurationSetName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.configurationSets)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly =
    zio.aws.sesv2.model.ListConfigurationSetsResponse.wrap(buildAwsValue())
}
object ListConfigurationSetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.ListConfigurationSetsResponse =
      zio.aws.sesv2.model.ListConfigurationSetsResponse(
        configurationSets.map(value => value),
        nextToken.map(value => value)
      )
    def configurationSets: Option[List[ConfigurationSetName]]
    def nextToken: Option[NextToken]
    def getConfigurationSets: ZIO[Any, AwsError, List[ConfigurationSetName]] =
      AwsError.unwrapOptionField("configurationSets", configurationSets)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ) extends zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly {
    override val configurationSets: Option[List[ConfigurationSetName]] = scala
      .Option(impl.configurationSets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sesv2.model.primitives.ConfigurationSetName(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.sesv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ): zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sesv2_3-5.19.7.1-sources.jar: zio/aws/sesv2/model/ListConfigurationSetsResponse.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.{NextToken, ConfigurationSetName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListConfigurationSetsResponse(
    configurationSets: Optional[Iterable[ConfigurationSetName]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse = {
    import ListConfigurationSetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
      .builder()
      .optionallyWith(
        configurationSets.map(value =>
          value.map { item =>
            ConfigurationSetName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.configurationSets)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly =
    zio.aws.sesv2.model.ListConfigurationSetsResponse.wrap(buildAwsValue())
}
object ListConfigurationSetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.ListConfigurationSetsResponse =
      zio.aws.sesv2.model.ListConfigurationSetsResponse(
        configurationSets.map(value => value),
        nextToken.map(value => value)
      )
    def configurationSets: Optional[List[ConfigurationSetName]]
    def nextToken: Optional[NextToken]
    def getConfigurationSets: ZIO[Any, AwsError, List[ConfigurationSetName]] =
      AwsError.unwrapOptionField("configurationSets", configurationSets)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ) extends zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly {
    override val configurationSets: Optional[List[ConfigurationSetName]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configurationSets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sesv2.model.primitives.ConfigurationSetName(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sesv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.ListConfigurationSetsResponse
  ): zio.aws.sesv2.model.ListConfigurationSetsResponse.ReadOnly = new Wrapper(
    impl
  )
}
